The main function for estimating a mixed-frequency BVAR.
estimate_mfbvar(mfbvar_prior = NULL, prior, variance = "iw", ...)a mfbvar_prior object
either "ss" (steady-state prior), "ssng" (hierarchical steady-state prior with normal-gamma shrinkage) or "minn" (Minnesota prior)
form of the error variance-covariance matrix: "iw" for the inverse Wishart prior, "diffuse" for a diffuse prior, "csv" for common stochastic volatility or "fsv" for factor stochastic volatility
additional arguments to update_prior (if mfbvar_prior is NULL, the arguments are passed on to set_prior)
An object of class mfbvar, mfbvar_<prior> and mfbvar_<prior>_<variance> containing posterior quantities as well as the prior object. For all choices of prior and variance, the returned object contains:
Array of dynamic coefficient matrices; Pi[,, r] is the rth draw
Array of monthly processes; Z[,, r] is the rth draw
Array of monthly forecasts; Z_fcst[,, r] is the rth forecast. The first n_lags
rows are taken from the data to offer a bridge between observations and forecasts and for computing nowcasts (i.e. with ragged edges).
prior = "ss", it also includes:
rootsThe maximum eigenvalue of the lag polynomial (if check_roots = TRUE)
If prior = "ssng", it also includes:
psiMatrix of steady-state parameter vectors; psi[r,] is the rth draw
rootsThe maximum eigenvalue of the lag polynomial (if check_roots = TRUE)
lambda_psiVector of draws of the global hyperparameter in the normal-Gamma prior
phi_psiVector of draws of the auxiliary hyperparameter in the normal-Gamma prior
omega_psiMatrix of draws of the prior variances of psi; omega_psi[r, ] is the rth draw, where diag(omega_psi[r, ]) is used as the prior covariance matrix for psi
variance = "iw" or variance = "diffuse", it also includes:
variance = "csv", it also includes:
phiVector of AR(1) parameters for the log-volatility regression; phi[r] is the rth draw
sigmaVector of error standard deviations for the log-volatility regression; sigma[r] is the rth draw
fMatrix of log-volatilities; f[r, ] is the rth draw
If variance = "fsv", it also includes:
latentArray of latent log-volatilities; latent[,, r] is the rth draw
muMatrix of means of the log-volatilities; mu[, r] is the rth draw
phiMatrix of AR(1) parameters for the log-volatilities; phi[, r] is the rth draw
sigmaMatrix of innovation variances for the log-volatilities; sigma[, r] is the rth draw
Ankargren, S., Unosson, M., & Yang, Y. (2020) A Flexible Mixed-Frequency Bayesian Vector Autoregression with a Steady-State Prior. Journal of Time Series Econometrics, 12(2), 10.1515/jtse-2018-0034. Ankargren, S., & Jon<U+00E9>us, P. (2020) Simulation Smoothing for Nowcasting with Large Mixed-Frequency VARs. Econometrics and Statistics, 10.1016/j.ecosta.2020.05.007. Ankargren, S., & Jon<U+00E9>us, P. (2019) Estimating Large Mixed-Frequency Bayesian VAR Models. arXiv:1912.02231, https://arxiv.org/abs/1912.02231. Kastner, G., & Huber, F. (2020) Sparse Bayesian Vector Autoregressions in Huge Dimensions. Journal of Forecasting, 39, 1142--1165. 10.1002/for.2680. Schorfheide, F., & Song, D. (2015) Real-Time Forecasting With a Mixed-Frequency VAR. Journal of Business & Economic Statistics, 33(3), 366--380. 10.1080/07350015.2014.954707
set_prior, update_prior, predict.mfbvar, plot.mfbvar_minn,
plot.mfbvar_ss, varplot, summary.mfbvar
# NOT RUN {
prior_obj <- set_prior(Y = mf_usa, n_lags = 4, n_reps = 20)
mod_minn <- estimate_mfbvar(prior_obj, prior = "minn")
# }
Run the code above in your browser using DataLab